package
Version:
v1.8.1
Opens a new window with list of versions in this module.
Published: Mar 27, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewDescribeCmd creates and returns a describe command.
type DescribeResponse struct {
SchemaVersion string `json:"schemaVersion"`
Command docs.Command `json:"command"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.