Documentation
¶
Index ¶
- func ConfigureProfile(io *iostreams.IOStreams, cfg config.IConfig, appDetails *dashboard.Application, ...) error
- func CreateAndFetchApplication(io *iostreams.IOStreams, client *dashboard.Client, ...) (*dashboard.Application, error)
- func CreateApplicationWithRetry(io *iostreams.IOStreams, client *dashboard.Client, accessToken string, ...) (*dashboard.Application, string, error)
- func EnsureAPIKey(io *iostreams.IOStreams, client *dashboard.Client, accessToken string, ...) error
- func PromptRegion(io *iostreams.IOStreams, client *dashboard.Client, accessToken string) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigureProfile ¶
func ConfigureProfile( io *iostreams.IOStreams, cfg config.IConfig, appDetails *dashboard.Application, profileName string, setDefault bool, ) error
ConfigureProfile creates a CLI profile from application details and optionally sets it as the default.
func CreateAndFetchApplication ¶
func CreateAndFetchApplication( io *iostreams.IOStreams, client *dashboard.Client, accessToken, region, appName string, ) (*dashboard.Application, error)
CreateAndFetchApplication creates an application (with region retry) and generates an API key for it.
func CreateApplicationWithRetry ¶
func CreateApplicationWithRetry( io *iostreams.IOStreams, client *dashboard.Client, accessToken string, region string, appName string, ) (*dashboard.Application, string, error)
CreateApplicationWithRetry creates an application, retrying with a different region if the selected one has no available cluster.
func EnsureAPIKey ¶
func EnsureAPIKey( io *iostreams.IOStreams, client *dashboard.Client, accessToken string, app *dashboard.Application, ) error
EnsureAPIKey generates a write API key for the application. Callers should skip this if the local profile already has a key.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.